@@ -4,5 +4,5 @@ int chr_dev_init()
 {
 	/* rs_init(); */
 	/* lp_init(); */
-	/* xtk_init(); */
+	xtk_init();
 }
